@@ -4,16 +4,14 @@ Main interface for outposts service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_outposts import (
         Client,
         OutpostsClient,
     )
 
-    session = boto3.Session()
-
-    client: OutpostsClient = boto3.client("outposts")
-    session_client: OutpostsClient = session.client("outposts")
+    session = Session()
+    client: OutpostsClient = session.client("outposts")
     ```
 """
 from .client import OutpostsClient
