@@ -21,9 +21,11 @@ else:
 
 __all__ = (
     "AddressTypeType",
+    "AssetStateType",
     "AssetTypeType",
     "CatalogItemClassType",
     "CatalogItemStatusType",
+    "ComputeAssetStateType",
     "FiberOpticCableTypeType",
     "LineItemStatusType",
     "MaximumSupportedWeightLbsType",
@@ -36,6 +38,7 @@ __all__ = (
     "PowerDrawKvaType",
     "PowerFeedDropType",
     "PowerPhaseType",
+    "ShipmentCarrierType",
     "SupportedHardwareTypeType",
     "SupportedStorageEnumType",
     "UplinkCountType",
@@ -48,9 +51,11 @@ __all__ = (
 
 
 AddressTypeType = Literal["OPERATING_ADDRESS", "SHIPPING_ADDRESS"]
+AssetStateType = Literal["ACTIVE", "RETIRING"]
 AssetTypeType = Literal["COMPUTE"]
 CatalogItemClassType = Literal["RACK", "SERVER"]
 CatalogItemStatusType = Literal["AVAILABLE", "DISCONTINUED"]
+ComputeAssetStateType = Literal["ACTIVE", "ISOLATED", "RETIRING"]
 FiberOpticCableTypeType = Literal["MULTI_MODE", "SINGLE_MODE"]
 LineItemStatusType = Literal[
     "BUILDING", "CANCELLED", "DELIVERED", "ERROR", "INSTALLED", "INSTALLING", "PREPARING", "SHIPPED"
@@ -87,11 +92,12 @@ OrderStatusType = Literal[
 ]
 OrderTypeType = Literal["OUTPOST", "REPLACEMENT"]
 PaymentOptionType = Literal["ALL_UPFRONT", "NO_UPFRONT", "PARTIAL_UPFRONT"]
-PaymentTermType = Literal["THREE_YEARS"]
+PaymentTermType = Literal["ONE_YEAR", "THREE_YEARS"]
 PowerConnectorType = Literal["AH530P7W", "AH532P6W", "IEC309", "L6_30P"]
 PowerDrawKvaType = Literal["POWER_10_KVA", "POWER_15_KVA", "POWER_5_KVA"]
 PowerFeedDropType = Literal["ABOVE_RACK", "BELOW_RACK"]
 PowerPhaseType = Literal["SINGLE_PHASE", "THREE_PHASE"]
+ShipmentCarrierType = Literal["DBS", "DHL", "FEDEX", "UPS"]
 SupportedHardwareTypeType = Literal["RACK", "SERVER"]
 SupportedStorageEnumType = Literal["EBS", "S3"]
 UplinkCountType = Literal[
@@ -138,6 +144,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -179,7 +186,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -257,6 +266,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -283,6 +293,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -311,6 +322,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -336,6 +348,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -346,12 +359,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
-    "redshiftserverless",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -397,6 +411,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -440,6 +455,7 @@ RegionName = Literal[
     "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ap-southeast-3",
     "ca-central-1",
     "eu-central-1",
     "eu-north-1",
